package cn.estsh.i3plus.pojo.aps.bean;

import cn.estsh.i3plus.pojo.aps.common.BaseAPS;
import cn.estsh.i3plus.pojo.aps.common.BeanRelation;
import cn.estsh.i3plus.pojo.aps.holders.EFurnacePlan;
import com.fasterxml.jackson.annotation.JsonBackReference;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiParam;
import lombok.Data;
import lombok.EqualsAndHashCode;
import org.hibernate.annotations.DynamicInsert;
import org.hibernate.annotations.DynamicUpdate;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.Table;
import java.util.List;

/**
 * @Description :炉资源计划信息，用来关联组在一起的工作计划
 * @Reference :
 * @Author : jason.niu
 * @CreateDate : 2019-10-22
 * @Modify:
 **/
@Data
@Entity
@DynamicInsert
@DynamicUpdate
@EqualsAndHashCode(callSuper = true)
@Table(name="APS_FURNACE_PLAN")
@Api("炉资源计划")
public class FurnacePlan extends BaseAPS {
    private static final long serialVersionUID = 6816465736285211114L;

    @Column(name="CAPACITY", columnDefinition = "decimal(18,8)")
    @ApiParam(value ="已占用的能力")
    private Double capacity;

    @Column(name="CAPACITY_LIMIT", columnDefinition = "decimal(18,8)")
    @ApiParam(value ="容量限制")
    private Double capacityLimit;

    @Column(name="MIN_PRODUCT_BATCH")
    @ApiParam(value ="最小加工批量")
    private Integer minProductBatch;

    @Column(name="FIX_PLAN")
    @ApiParam(value ="固定组炉的计划")
    private Boolean fixPlan;

    @Column(name="MERGE_PLAN_ID")
    @ApiParam(value ="合并炉计划")
    private Long mergePlanId;

    @JsonBackReference
    public List<WorkPlan> getWorkPlans() { return BeanRelation.list(this, EFurnacePlan.WorkPlans); }

    public FurnacePlan getMergePlan() {
        return BeanRelation.get(this, EFurnacePlan.MergePlan);
    }

    public void setMergePlan(FurnacePlan plan) {
        this.mergePlanId = plan != null ? plan.getId() : 0L;
        BeanRelation.set(this, EFurnacePlan.MergePlan, plan);
    }

    @JsonBackReference
    public FurnacePlan getOriginMergePlan() {
        return BeanRelation.get(this, EFurnacePlan.OriginMergePlan);
    }
}
